@@ -54,13 +54,7 @@ class Bundle(object):
         # Build the list of BundleFiles
         self.files = []
 
-        conf_files = list(conf_dict['files'])
-
-        if self.name in bundles_settings.BUNDLES_OVERRIDE:
-            conf_files = list(bundles_settings.BUNDLES_OVERRIDE[self.name].get('files_prepend', [])) + conf_files
-            conf_files = conf_files + list(bundles_settings.BUNDLES_OVERRIDE[self.name].get('files_append', []))
-
-        for fileconf in conf_files:
+        for fileconf in list(conf_dict['files']):
             path, extra = fileconf, None
             # Each file definition can be a string or tuple containing the path and the conf dict
             if isinstance(fileconf, (tuple, list)):
